@@ -5,7 +5,7 @@ from typing import Any, Optional, Union, Callable, List
 
 
 def get_log_msg(contents: dict,
-                default_tz: Optional[Union[str, timezone]] = None) -> str:
+                default_tz: Optional[Union[str, timezone]] = None) -> str | None:
     """
     获得日志
     """
@@ -33,6 +33,8 @@ def get_log_msg(contents: dict,
             content = content[len(time_str):].strip()
             if _time_ is None:
                 _time_ = to_datetime_str(time_str, default_tz=default_tz)
+    if content is None:
+        return None
     return ' '.join(filter(lambda s: s is not None, [_time_, level, content.replace('\n', '\\n').replace('\t', '\\t')]))
 
 
